package VMOMI::HostAccessMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
